@@ -50,7 +50,8 @@ class ValidateDockerPlugin(EnvCommand):
         required_packages = self.poetry.package.requires
         for package in required_packages:
             name = package.pretty_name
-            if name in docker_deps:
+            # Defer to poetry.lock validation if dpeendency is a direct origin source such as git, local path, etc.
+            if not package.is_direct_origin() and name in docker_deps:
                 if Package(name, docker_deps[name]).satisfies(package):
                     docker_deps.pop(name)
                 else:
@@ -83,7 +84,7 @@ class ValidateDockerPlugin(EnvCommand):
                         f"but docker container {cid} has {name}=={proc_version}"
                     )
 
-    def handle(self) -> None:
+    def handle(self) -> int:
         cid = self.argument("containerId")
         self.line(f"Fetching 'pip freeze' from docker image {cid} and validating against pyproject.toml/poetry.lock")
 
@@ -101,3 +102,5 @@ class ValidateDockerPlugin(EnvCommand):
             f"Validation success!  Docker image {cid} has consistent versions with dependencies specified "
             f"in this project"
         )
+
+        return 0
